@@ -31,3 +31,9 @@ class PackEnum(object):
     @staticmethod
     def create(p):
         return None
+
+class EventLevel(object):
+    FATAL = 30
+    WARNING = 20
+    INFO = 10
+    NONE = 0
