@@ -36,10 +36,12 @@ def sendDebugProfile(ctx, msg):
         datas = [' ', ' ', 'DEBUG: ' + msg]
         UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
-def trace_handler(fn, start=False):
+def trace_handler(fn, start=False, preload=None):
     def handler(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
+            if preload:
+                preload(*args, **kwargs)
             # if isEventlet():
             #     print("trace_handler: greenlet found")
             # else:
@@ -262,16 +264,16 @@ def interceptor_step_error(e, ctx = None):
     ctx.error_step = e
     if not ctx.error:
         ctx.error = 1
-    
+        
     errors = []
     errors.append(e.__class__.__name__)
     errors.append(str(e.args[0]))
-    
+
     error = ''
     frame = sys._current_frames().get(ctx.thread.ident)
     if not frame:
         return
-    
+
     for stack in traceback.extract_stack(frame):
         line = stack[0]
         line_num = stack[1]
@@ -280,7 +282,7 @@ def interceptor_step_error(e, ctx = None):
         if line.find('/whatap/trace') > -1 or line.find('/threading.py') > -1:
             continue
         error += '{} ({}:{})\n'.format(method_name,line, line_num)
-    
+
     errors.append(error)
     # errors.append(''.join(traceback.format_list(traceback.extract_stack(sys._current_frames()[ctx.thread.ident]))))
     UdpSession.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
